@@ -383,16 +383,17 @@ impl Contract {
     /// To deploy a contract, you need a wallet with enough assets to pay for deployment. This
     /// wallet will also receive the change.
     pub async fn deploy(
-        compiled_contract: &CompiledContract,
-        provider: &Provider,
+        binary_filepath: &str,
         wallet: &LocalWallet,
         params: TxParameters,
     ) -> Result<ContractId, Error> {
+        let compiled_contract = Contract::load_sway_contract(binary_filepath).unwrap();
+
         let (mut tx, contract_id) =
-            Self::contract_deployment_transaction(compiled_contract, wallet, params).await?;
+            Self::contract_deployment_transaction(&compiled_contract, wallet, params).await?;
         wallet.sign_transaction(&mut tx).await?;
 
-        match provider.client.submit(&tx).await {
+        match wallet.provider.client.submit(&tx).await {
             Ok(_) => Ok(contract_id),
             Err(e) => Err(Error::TransactionError(e.to_string())),
         }
@@ -569,14 +570,14 @@ where
 
     /// Call a contract's method on the node, in a state-modifying manner.
     pub async fn call(self) -> Result<CallResponse<D>, Error> {
-        Ok(Self::call_or_simulate(self, false).await?)
+        Self::call_or_simulate(self, false).await
     }
 
     /// Call a contract's method on the node, in a simulated manner, meaning the state of the
     /// blockchain is *not* modified but simulated.
     /// It is the same as the `call` method because the API is more user-friendly this way.
     pub async fn simulate(self) -> Result<CallResponse<D>, Error> {
-        Ok(Self::call_or_simulate(self, true).await?)
+        Self::call_or_simulate(self, true).await
     }
 
     /// Based on the returned Contract's output_params and the receipts returned from the call,
